@@ -67,7 +67,7 @@ date
 let shape_name = namespace.make_shape("BadDateValue".parse().unwrap());
 let mut body = StructureOrUnion::new();
 body.add_member(
-    shape_name.make_member("errorMessage".parse().unwrap()),
+    "errorMessage".parse().unwrap(),
     prelude.make_shape("String".parse().unwrap()),
 );
 let mut error = TopLevelShape::new(shape_name, ShapeKind::Structure(body));
@@ -82,7 +82,7 @@ error
 let shape_name = namespace.make_shape("GetMessageOutput".parse().unwrap());
 let mut output = StructureOrUnion::new();
 let mut message = MemberShape::new(
-    shape_name.make_member("message".parse().unwrap()),
+    "message".parse().unwrap(),
     prelude.make_shape("String".parse().unwrap()),
 );
 message
@@ -98,7 +98,7 @@ let output = TopLevelShape::new(
 let shape_name = namespace.make_shape("GetMessageInput".parse().unwrap());
 let mut input = StructureOrUnion::new();
 input.add_member(
-    shape_name.make_member("date".parse().unwrap()),
+    "date".parse().unwrap(),
     date.id().clone(),
 );
 let input = TopLevelShape::new(
