@@ -233,9 +233,6 @@ pub trait Shape: NonTraitEq + HasIdentity + HasTraits {
     fn is_prelude_shape(&self) -> bool {
         self.id().namespace().to_string() == *PRELUDE_NAMESPACE
     }
-
-    /// Is this instance a member (or top-level) shape?
-    fn is_member(&self) -> bool;
 }
 
 ///
@@ -407,12 +404,6 @@ impl HasIdentity for TopLevelShape {
 
 has_traits_impl! { TopLevelShape . traits }
 
-impl Shape for TopLevelShape {
-    fn is_member(&self) -> bool {
-        false
-    }
-}
-
 lazy_static! {
     static ref MEMBER_MEMBER: Identifier = Identifier::from_str("member").unwrap();
     static ref MEMBER_KEY: Identifier = Identifier::from_str("key").unwrap();
